@@ -14,7 +14,9 @@
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
-"""General navigation writer reading .nav file info"""
+"""
+General navigation writer reading .nav file info.
+"""
 
 import sys
 import os
