@@ -36,8 +36,15 @@ import linkcheck.strformat
 import linkcheck.dns.exception
 
 
-# we catch these exceptions, all other exceptions are internal
-# or system errors
+# Catch these exception on syntax checks.
+ExcSyntaxList = [
+    linkcheck.LinkCheckerError,
+    # .encode('idna') raises this
+    UnicodeError,
+]
+
+# Catch these exceptions on content and connect checks. All other
+# exceptions are internal or system errors
 ExcCacheList = [
     IOError,
     OSError, # OSError is thrown on Windows when a file is not found
@@ -146,7 +153,8 @@ acap        # application configuration access protocol
 
 ignored_schemes_re = re.compile(ignored_schemes, re.VERBOSE)
 
-stderr = codecs.getwriter("iso8859-1")(sys.stderr, errors="ignore")
+_encoding = linkcheck.i18n.default_encoding
+stderr = codecs.getwriter(_encoding)(sys.stderr, errors="ignore")
 
 def internal_error ():
     """
@@ -189,17 +197,6 @@ def print_app_info ():
             print >> stderr, key, "=", repr(value)
 
 
-def abort (consumer):
-    """
-    Try to abort consumer. Exit on errors.
-    """
-    try:
-        consumer.abort()
-    except:
-        # XXX print an error message?
-        sys.exit(1)
-
-
 def check_urls (consumer):
     """
     Main check function; checks all configured URLs until interrupted
@@ -213,10 +210,10 @@ def check_urls (consumer):
     """
     try:
         _check_urls(consumer)
-    except KeyboardInterrupt:
-        abort(consumer)
+    except (KeyboardInterrupt, SystemExit):
+        consumer.abort()
     except:
-        abort(consumer)
+        consumer.abort()
         internal_error()
 
 
@@ -388,4 +385,3 @@ def get_index_html (urls):
         lines.append('<a href="%s">%s</a>' % (url, name))
     lines.extend(["</body>", "</html>"])
     return os.linesep.join(lines)
-
