@@ -20,7 +20,6 @@ Handle local file: links.
 
 import re
 import os
-import os.path
 import time
 import urlparse
 import urllib
@@ -106,7 +105,8 @@ class FileUrl (urlbase.UrlBase):
         base_url = re.sub("^file://(/?)([a-zA-Z]):", r"file:///\2|", base_url)
         # norm base url again after changing
         if self.base_url != base_url:
-            self.base_url, is_idn = linkcheck.url.url_norm(base_url)
+            base_url, is_idn = linkcheck.url.url_norm(base_url)
+            self.base_url = unicode(base_url)
 
     def build_url (self):
         """
@@ -277,4 +277,3 @@ class FileUrl (urlbase.UrlBase):
             segments = segments[:-1]
         path = "/".join(segments)
         return "file://%s" % re.escape(path)
-
