@@ -49,7 +49,7 @@ _is_amazon = re.compile(r'^www\.amazon\.(com|de|ca|fr|co\.(uk|jp))').search
 httpresponses = {
     100: 'Continue',
     101: 'Switching Protocols',
-    
+
     200: 'OK',
     201: 'Created',
     202: 'Accepted',
@@ -57,7 +57,7 @@ httpresponses = {
     204: 'No Content',
     205: 'Reset Content',
     206: 'Partial Content',
-    
+
     300: 'Multiple Choices',
     301: 'Moved Permanently',
     302: 'Found',
@@ -66,7 +66,7 @@ httpresponses = {
     305: 'Use Proxy',
     306: '(Unused)',
     307: 'Temporary Redirect',
-    
+
     400: 'Bad Request',
     401: 'Unauthorized',
     402: 'Payment Required',
@@ -85,7 +85,7 @@ httpresponses = {
     415: 'Unsupported Media Type',
     416: 'Requested Range Not Satisfiable',
     417: 'Expectation Failed',
-    
+
     500: 'Internal Server Error',
     501: 'Not Implemented',
     502: 'Bad Gateway',
@@ -308,17 +308,27 @@ class HttpUrl (internpaturl.InternPatternUrl, proxysupport.ProxySupport):
             redirected, is_idn = linkcheck.url.url_norm(newurl)
             linkcheck.log.debug(linkcheck.LOG_CHECK, "Norm redirected to %r",
                                 redirected)
+            urlparts = linkcheck.strformat.url_unicode_split(redirected)
+            # check if we still have the same scheme type, it could be a
+            # different one
+            if urlparts[0] != self.scheme:
+                self.add_warning(
+                           _("Redirection to different URL type encountered; "
+                             "the original URL was %r.") % self.url,
+                           tag="http-wrong-redirect")
             # check extern filter again
             self.set_extern(redirected)
             if self.extern[0] and self.extern[0]:
                 self.add_info(
-                          _("Outside of domain filter, checked only syntax."))
+                          _("The redirected URL is outside of the domain " \
+                            "filter, checked only syntax."))
                 self.set_result(u"filtered")
                 return -1, response
             # check robots.txt allowance again
             if not self.allows_robots(redirected):
                 self.add_warning(
-                       _("Access denied by robots.txt, checked only syntax."),
+                       _("Access to redirected URL denied by robots.txt, " \
+                         "checked only syntax."),
                        tag="http-robots-denied")
                 self.set_result(u"syntax OK")
                 return -1, response
@@ -337,7 +347,7 @@ class HttpUrl (internpaturl.InternPatternUrl, proxysupport.ProxySupport):
             # remember redireced url as alias
             self.aliases.append(redirected)
             # note: urlparts has to be a list
-            self.urlparts = linkcheck.strformat.url_unicode_split(redirected)
+            self.urlparts = urlparts
             if response.status == 301:
                 if not self.has301status:
                     self.add_warning(
@@ -348,20 +358,14 @@ class HttpUrl (internpaturl.InternPatternUrl, proxysupport.ProxySupport):
             # check cache again on the changed URL
             if self.consumer.checked_redirect(redirected, self):
                 return -1, response
-            # check if we still have a http url, it could be another
-            # scheme, eg https or news
-            if self.urlparts[0] != "http":
-                self.add_warning(
-                           _("HTTP redirection to non-http url encountered; "
-                             "the original url was %r.") % self.url,
-                           tag="http-wrong-redirect")
-                # make new Url object
+            # in case of changed scheme make new URL object
+            if self.urlparts[0] != self.scheme:
                 newobj = linkcheck.checker.get_url_from(
                           redirected, self.recursion_level, self.consumer,
                           parent_url=self.parent_url, base_ref=self.base_ref,
                           line=self.line, column=self.column, name=self.name,
                           cmdline=False)
-                newobj.warning = self.warning
+                newobj.warnings = self.warnings
                 newobj.info = self.info
                 # append new object to queue
                 self.consumer.append_url(newobj)
@@ -617,4 +621,3 @@ class HttpUrl (internpaturl.InternPatternUrl, proxysupport.ProxySupport):
                 # ignore close errors
                 pass
         self.url_connection = None
-
