@@ -27,9 +27,14 @@ class IgnoredUrl (urlbase.UrlBase):
 
     def local_check (self):
         """
-        Only logs a warning that this URL is ignored.
+        Only logs that this URL is ignored.
         """
-        self.add_warning(_("%s URL ignored.") % self.scheme.capitalize())
+        self.set_extern(self.url)
+        if self.extern[0] and self.extern[1]:
+            self.add_info(_("Outside of domain filter, checked only syntax."))
+        else:
+            self.add_warning(_("%s URL ignored.") % self.scheme.capitalize(),
+                             tag="ignore-url")
 
     def can_get_content (self):
         """
