@@ -19,6 +19,7 @@ Mixin class for URLs that can be fetched over a proxy.
 """
 
 import urllib
+import linkcheck
 
 class ProxySupport (object):
     """
@@ -36,7 +37,10 @@ class ProxySupport (object):
         if not self.proxy:
             return
         if self.proxy[:7].lower() != "http://":
-            self.proxy = "http://"+self.proxy
+            # Note that invalid proxies might raise TypeError in urllib2,
+            # so make sure to stop checking at this point, not later.
+            msg = _("Proxy value %r must start with 'http://'.") % self.proxy
+            raise linkcheck.LinkCheckerError(msg)
         self.proxy = urllib.splittype(self.proxy)[1]
         self.proxy = urllib.splithost(self.proxy)[0]
         self.proxyauth, self.proxy = urllib.splituser(self.proxy)
