@@ -234,12 +234,12 @@ class Configuration (dict):
             # system wide config settings
             config_dir = _linkchecker_configdata.config_dir
             path = normpath(os.path.join(config_dir, "linkcheckerrc"))
-            if os.path.exists(path):
-                cfiles.append(path)
+            cfiles.append(path)
             # per user config settings
             path = normpath("~/.linkchecker/linkcheckerrc")
-            if os.path.exists(path):
-                cfiles.append(path)
+            cfiles.append(path)
+        # weed out invalid files
+        cfiles = [f for f in cfiles if os.path.isfile(f)]
         self.read_config(cfiles)
         # re-init logger
         self['logger'] = self.logger_new('text')
@@ -414,13 +414,9 @@ class Configuration (dict):
         try:
             i = 1
             while 1:
-                ctuple = cfgparser.get(section, "nofollow%d" % i).split()
-                if len(ctuple)!=2:
-                    linkcheck.log.error(
-                            _("nofollow%d: syntax error %s\n") % (i, ctuple))
-                    break
-                self["externlinks"].append(
-                    linkcheck.get_link_pat(ctuple[0], strict=0))
+                val = cfgparser.get(section, "nofollow%d" % i)
+                pat = linkcheck.get_link_pat(val, strict=0)
+                self["externlinks"].append(pat)
                 i += 1
         except ConfigParser.Error, msg:
             linkcheck.log.debug(linkcheck.LOG_CHECK, msg)
@@ -432,13 +428,10 @@ class Configuration (dict):
         try:
             i = 1
             while 1:
-                ctuple = cfgparser.get(section, "ignore%d" % i).split()
-                if len(ctuple)!=2:
-                    linkcheck.log.error(
-                            _("ignore%d: syntax error %s\n") % (i, ctuple))
-                    break
-                self["externlinks"].append(
-                    linkcheck.get_link_pat(ctuple[0], strict=1))
+                # XXX backwards compatibility: split and ignore second part
+                val = cfgparser.get(section, "ignore%d" % i).split()[0]
+                pat = linkcheck.get_link_pat(val, strict=1)
+                self["externlinks"].append(pat)
                 i += 1
         except ConfigParser.Error, msg:
             linkcheck.log.debug(linkcheck.LOG_CHECK, msg)
@@ -486,4 +479,3 @@ class Configuration (dict):
         """
         fp.write("[filtering]%s" % os.linesep)
         # XXX todo
-
