@@ -245,8 +245,10 @@ class Message(object):
     def is_response(self, other):
         """Is other a response to self?
         @rtype: bool"""
+        if self.id != other.id:
+            linkcheck.log.warn(linkcheck.LOG_DNS,
+                "DNS message IDs differ\n%s\n----\n%s\n----", self, other)
         if other.flags & linkcheck.dns.flags.QR == 0 or \
-           self.id != other.id or \
            linkcheck.dns.opcode.from_flags(self.flags) != \
            linkcheck.dns.opcode.from_flags(other.flags):
             return False
@@ -445,6 +447,21 @@ class Message(object):
         if self.ednsflags != 0 and self.edns < 0:
             self.edns = 0
 
+    def opcode(self):
+        """Return the opcode.
+        @rtype: int
+        """
+        return linkcheck.dns.opcode.from_flags(self.flags)
+
+    def set_opcode(self, opcode):
+        """Set the opcode.
+        @param opcode: the opcode
+        @type opcode: int
+        """
+        self.flags &= 0x87FF
+        self.flags |= linkcheck.dns.opcode.to_flags(opcode)
+
+
 class _WireReader(object):
     """Wire format reader.
 
@@ -903,3 +920,39 @@ def make_query(qname, rdtype, rdclass = linkcheck.dns.rdataclass.IN):
     m.find_rrset(m.question, qname, rdclass, rdtype, create=True,
                  force_unique=True)
     return m
+
+
+def make_response(query, recursion_available=False, our_payload=8192):
+    """Make a message which is a response for the specified query.
+    The message returned is really a response skeleton; it has all
+    of the infrastructure required of a response, but none of the
+    content.
+
+    The response's question section is a shallow copy of the query's
+    question section, so the query's question RRsets should not be
+    changed.
+
+    @param query: the query to respond to
+    @type query: linkcheck.dns.message.Message object
+    @param recursion_available: should RA be set in the response?
+    @type recursion_available: bool
+    @param our_payload: payload size to advertise in EDNS responses; default
+    is 8192.
+    @type our_payload: int
+    @rtype: linkcheck.dns.message.Message object"""
+
+    if query.flags & linkcheck.dns.flags.QR:
+        raise linkcheck.dns.exception.FormError, 'specified query message is not a query'
+    response = linkcheck.dns.message.Message(query.id)
+    response.flags = linkcheck.dns.flags.QR | (query.flags & linkcheck.dns.flags.RD)
+    if recursion_available:
+        response.flags |= linkcheck.dns.flags.RA
+    response.set_opcode(query.opcode())
+    response.question = list(query.question)
+    if query.edns >= 0:
+        response.use_edns(0, 0, our_payload, query.payload)
+    if not query.keyname is None:
+        response.keyname = query.keyname
+        response.keyring = query.keyring
+        response.request_mac = query.mac
+    return response
