@@ -68,6 +68,11 @@ class AbsoluteConcatenation(linkcheck.dns.exception.DNSException):
     empty name to an absolute name."""
     pass
 
+class NoParent(linkcheck.dns.exception.DNSException):
+    """Raised if an attempt is made to get the parent of the root name
+    or the empty name."""
+    pass
+
 _escaped = {
     '"' : True,
     '(' : True,
@@ -480,6 +485,16 @@ class Name(object):
         else:
             return self
 
+    def parent(self):
+        """Return the parent of the name.
+        @rtype: linkcheck.dns.name.Name object
+        @raises NoParent: the name is either the root name or the enpty name
+        and thus has no parent.
+        """
+        if self == root or self == empty:
+            raise NoParent
+        return Name(self.labels[1:])
+
 root = Name([''])
 empty = Name([])
 
@@ -494,6 +509,7 @@ def from_text(text, origin = root):
         raise ValueError, "origin must be a Name or None"
     labels = []
     label = ''
+    edigits = 0
     escaping = False
     if text == '@':
         text = ''
