@@ -24,7 +24,6 @@ import unittest
 import difflib
 
 import linkcheck
-linkcheck.init_i18n()
 import linkcheck.checker
 import linkcheck.checker.cache
 import linkcheck.checker.consumer
@@ -144,7 +143,7 @@ class StandardTest (unittest.TestCase):
         """
         resultfile = self.get_file(filename+".result")
         d = {'curdir': os.getcwd()}
-        f = codecs.open(resultfile, "r", "iso8859-1")
+        f = codecs.open(resultfile, "r", "iso-8859-15")
         resultlines = [line.rstrip('\r\n') % d for line in f \
                        if line.strip() and not line.startswith(u'#')]
         f.close()
