@@ -55,7 +55,7 @@ class TestFtp (linkcheck.ftests.StandardTest):
             u"url %s" % url,
             u"cache key %s" % nurl,
             u"real url %s" % nurl,
-            u"warning Base URL is not properly normed. Normed url is %s." % nurl,
+            u"warning Base URL is not properly normed. Normed URL is %s." % nurl,
             u"error",
         ]
         self.direct(url, resultlines)
@@ -92,7 +92,7 @@ class TestFtp (linkcheck.ftests.StandardTest):
             u"url %s" % url,
             u"cache key %s" % nurl,
             u"real url %s" % nurl,
-            u"warning Base URL is not properly normed. Normed url is %s." % nurl,
+            u"warning Base URL is not properly normed. Normed URL is %s." % nurl,
             u"valid",
         ]
         self.direct(url, resultlines)
@@ -103,7 +103,7 @@ class TestFtp (linkcheck.ftests.StandardTest):
             u"url %s" % url,
             u"cache key %s" % nurl,
             u"real url %s" % nurl,
-            u"warning Base URL is not properly normed. Normed url is %s." % nurl,
+            u"warning Base URL is not properly normed. Normed URL is %s." % nurl,
             u"valid",
         ]
         self.direct(url, resultlines)
@@ -122,9 +122,7 @@ def test_suite ():
     """
     Build and return a TestSuite.
     """
-    suite = unittest.TestSuite()
-    suite.addTest(unittest.makeSuite(TestFtp))
-    return suite
+    return unittest.makeSuite(TestFtp)
 
 
 if __name__ == '__main__':
