@@ -47,9 +47,7 @@ def test_suite ():
     """
     Build and return a TestSuite.
     """
-    suite = unittest.TestSuite()
-    suite.addTest(unittest.makeSuite(TestHttps))
-    return suite
+    return unittest.makeSuite(TestHttps)
 
 
 if __name__ == '__main__':
