@@ -39,9 +39,7 @@ def test_suite ():
     """
     Build and return a TestSuite.
     """
-    suite = unittest.TestSuite()
-    suite.addTest(unittest.makeSuite(TestRobotsTxt))
-    return suite
+    return unittest.makeSuite(TestRobotsTxt)
 
 
 if __name__ == '__main__':
