@@ -148,10 +148,13 @@ class MetaRobotsFinder (TagFinder):
 
 
 def is_meta_url (attr, attrs):
+    """
+    Check if the meta attributes contain a URL.
+    """
     res = False
     if attr == "content":
         equiv = attrs.get_true('http-equiv', u'').lower()
-	scheme = attrs.get_true('scheme', u'').lower()
+        scheme = attrs.get_true('scheme', u'').lower()
         res = equiv in (u'refresh',) or scheme in (u'dcterms.uri',)
     if attr == "href":
         rel = attrs.get_true('rel', u'').lower()
@@ -250,7 +253,7 @@ class LinkFinder (TagFinder):
             mo = refresh_re.match(url)
             if mo:
                 urls.append(mo.group("url"))
-            else:
+            elif attr != 'content':
                 urls.append(url)
         elif attr == u'style':
             for mo in css_url_re.finditer(url):
