@@ -18,13 +18,12 @@
 Output logging support for different formats.
 """
 
-import locale
 import sys
 import os
-import os.path
 import datetime
 
 import linkcheck.strformat
+import linkcheck.i18n
 
 _ = lambda x: x
 Fields = dict(
@@ -70,7 +69,8 @@ class Logger (object):
         # number of encountered warningss
         self.warnings = 0
         # encoding of output
-        self.output_encoding = args.get("encoding", locale.getpreferredencoding())
+        default = linkcheck.i18n.default_encoding
+        self.output_encoding = args.get("encoding", default)
 
     def init_fileoutput (self, args):
         """
