@@ -33,18 +33,17 @@ class TestFilenames (unittest.TestCase):
         realpath = get_nt_filename(path)
         self.assertEquals(path, realpath)
         if os.name == 'nt':
-            path = 'c:\\winnt'
+            path = 'c:\\'
             realpath = get_nt_filename(path)
-            # XXX assert?
+            self.assertEquals(path, realpath)
 
 
 def test_suite ():
     """
     Build and return a TestSuite.
     """
-    suite = unittest.TestSuite()
-    suite.addTest(unittest.makeSuite(TestFilenames))
-    return suite
+    return unittest.makeSuite(TestFilenames)
+
 
 if __name__ == '__main__':
     unittest.main()
