@@ -49,6 +49,9 @@ parsetests = [
     ("""< a >""", """<a>"""),
     ("""<>""", """<>"""),
     ("""< >""", """< >"""),
+    ("""<a>""", """<a>"""),
+    ("""<a a="b">""", """<a a="b">"""),
+    ("""<a a="b">""", """<a a="b">"""),
     # reduce test
     ("""<a  b="c"><""", """<a b="c"><"""),
     ("""d>""", """d>"""),
@@ -79,6 +82,7 @@ parsetests = [
     ("""</a >""", """</a>"""),
     ("""< / a>""", """</a>"""),
     ("""< /a>""", """</a>"""),
+    ("""</a>""", """</a>"""),
     # missing > in end tag
     ("""</td <td  a="b" >""", """</td><td a="b">"""),
     # start and end tag (HTML doctype assumed)
