@@ -192,6 +192,7 @@ def idna_encode (host):
     """
     Encode hostname as internationalized domain name (IDN) according
     to RFC 3490.
+    @raise: UnicodeError if hostname is not properly IDN encoded.
     """
     if host and isinstance(host, unicode):
         uhost = host.encode('idna').decode('ascii')
@@ -270,14 +271,14 @@ def url_parse_query (query):
     # if ? is in the query, split it off, seen at msdn.microsoft.com
     if '?' in query:
         query, append = query.split('?', 1)
-        append = '?'+append
+        append = '?'+url_parse_query(append)
     else:
         append = ""
     l = []
     for k, v, sep in parse_qsl(query, True):
-        k = urllib.quote(k, '/-:,;')
+        k = url_quote_part(k, '/-:,;')
         if v:
-            v = urllib.quote(v, '/-:,;')
+            v = url_quote_part(v, '/-:,;')
             l.append("%s=%s%s" % (k, v, sep))
         elif v is None:
             l.append("%s%s" % (k, sep))
@@ -317,14 +318,19 @@ def url_norm (url):
         else:
             # fix redundant path parts
             urlparts[2] = collapse_segments(urlparts[2])
+    # anchor
+    urlparts[4] = urllib.unquote(urlparts[4])
     # quote parts again
-    urlparts[0] = urllib.quote(urlparts[0]) # scheme
-    urlparts[1] = urllib.quote(urlparts[1], '@:') # host
-    urlparts[2] = urllib.quote(urlparts[2], _nopathquote_chars) # path
+    urlparts[0] = url_quote_part(urlparts[0]) # scheme
+    urlparts[1] = url_quote_part(urlparts[1], '@:') # host
+    urlparts[2] = url_quote_part(urlparts[2], _nopathquote_chars) # path
+    urlparts[4] = url_quote_part(urlparts[4]) # anchor
     res = urlparse.urlunsplit(urlparts)
     if url.endswith('#') and not urlparts[4]:
         # re-append trailing empty fragment
         res += '#'
+    if isinstance(url, unicode):
+        res = unicode(res)
     return (res, is_idn)
 
 
@@ -378,29 +384,39 @@ def url_quote (url):
     if not url_is_absolute(url):
         return document_quote(url)
     urlparts = list(urlparse.urlsplit(url))
-    urlparts[0] = urllib.quote(urlparts[0]) # scheme
-    urlparts[1] = urllib.quote(urlparts[1], ':') # host
-    urlparts[2] = urllib.quote(urlparts[2], '/=,') # path
-    urlparts[3] = urllib.quote(urlparts[3], '&=,') # query
+    urlparts[0] = url_quote_part(urlparts[0]) # scheme
+    urlparts[1] = url_quote_part(urlparts[1], ':') # host
+    urlparts[2] = url_quote_part(urlparts[2], '/=,') # path
+    urlparts[3] = url_quote_part(urlparts[3], '&=,') # query
     l = []
     for k, v, sep in parse_qsl(urlparts[3], True): # query
-        k = urllib.quote(k, '/-:,')
+        k = url_quote_part(k, '/-:,')
         if v:
-            v = urllib.quote(v, '/-:,')
+            v = url_quote_part(v, '/-:,')
             l.append("%s=%s%s" % (k, v, sep))
         else:
             l.append("%s%s" % (k, sep))
     urlparts[3] = ''.join(l)
-    urlparts[4] = urllib.quote(urlparts[4]) # anchor
+    urlparts[4] = url_quote_part(urlparts[4]) # anchor
     return urlparse.urlunsplit(urlparts)
 
 
+def url_quote_part (s, safechars='/'):
+    """
+    Wrap urllib.quote() to support unicode strings. A unicode string
+    is first converted to ISO-8859-1, invalid characters are ignored.
+    After that urllib.quote() is called.
+    """
+    if isinstance(s, unicode):
+        s = s.encode("iso-8859-1", "ignore")
+    return urllib.quote(s, safechars)
+
 def document_quote (document):
     """
     Quote given document.
     """
     doc, query = urllib.splitquery(document)
-    doc = urllib.quote(doc, '/=,')
+    doc = url_quote_part(doc, '/=,')
     if query:
         return "%s?%s" % (doc, query)
     return doc
@@ -430,7 +446,7 @@ def match_host (host, domainlist):
     return False
 
 
-_nopathquote_chars = "-;/=,~*+()@"
+_nopathquote_chars = "-;/=,~*+()@!"
 if os.name == 'nt':
     _nopathquote_chars += "|"
 _safe_url_chars = re.escape(_nopathquote_chars + "_:.&#%?[]!")+"a-zA-Z0-9"
@@ -462,4 +478,3 @@ def url_split (url):
         host = host.lower()
         host, port = urllib.splitnport(host, port)
     return scheme, host, port, document
-
