@@ -63,8 +63,7 @@ Options:
   --search-in dir       limit directory tree walk to dir (optimisation)
   --immediate-errors    show errors as soon as they happen (default)
   --delayed-errors      show errors after all unit tests were run
-  --resource name       enable given resource; currently only 'network'
-                        is allowed
+  --resource name       enable given resource
 """
 #
 # This script borrows ideas from Zope 3's test runner heavily.  It is smaller
@@ -86,8 +85,6 @@ from sets import Set
 __metaclass__ = type
 
 
-Resources = ['network']
-
 class TestSkipped (Exception):
     """Test skipped.
 
@@ -190,6 +187,16 @@ def walk_with_symlinks(top, func, arg):
                 walk_with_symlinks(name, func, arg)
 
 
+def has_path_component (path, name):
+    drive, path = os.path.splitdrive(path)
+    head, tail = os.path.split(path)
+    while head and tail:
+        if tail == name:
+            return True
+        head, tail = os.path.split(head)
+    return False
+
+
 def get_test_files(cfg):
     """Return a list of test module filenames."""
     matcher = compile_matcher(cfg.pathname_regex)
@@ -203,30 +210,36 @@ def get_test_files(cfg):
     def visit(ignored, dir, files):
         # Ignore files starting with a dot.
         # Do not not descend into subdirs containing a dot.
+        # Ignore versioning system files
         remove = []
         for idx, file in enumerate(files):
             if file.startswith('.'):
                 remove.append(idx)
             elif '.' in file and os.path.isdir(os.path.join(dir, file)):
                 remove.append(idx)
+            elif file in ["CVS", ".svn", ".git"]:
+                remove.append(idx)
         remove.reverse()
         for idx in remove:
             del files[idx]
         # Skip non-test directories, but look for tests.py and/or ftests.py
-        if os.path.basename(dir) != test_name:
+        if not has_path_component(dir, test_name):
             if test_name + '.py' in files:
                 path = os.path.join(dir, test_name + '.py')
                 if matcher(path[baselen:]):
                     results.append(path)
             return
+        test_files = [f for f in files if \
+                      f.startswith('test') and f.endswith(".py")]
         if '__init__.py' not in files:
-            print >> sys.stderr, "%s is not a package" % dir
+            if test_files:
+                # Python test files found, but no __init__.py
+                print >> sys.stderr, "%s is not a package" % dir
             return
-        for file in files:
-            if file.startswith('test') and file.endswith('.py'):
-                path = os.path.join(dir, file)
-                if matcher(path[baselen:]):
-                    results.append(path)
+        for file in test_files:
+            path = os.path.join(dir, file)
+            if matcher(path[baselen:]):
+                results.append(path)
     if cfg.follow_symlinks:
         walker = walk_with_symlinks
     else:
@@ -705,7 +718,7 @@ class CustomTestResult(unittest._TextTestResult):
         self.__super_printErrors()
 
     def printSkipped (self):
-        self.printErrorList("SKIP", self.skipped)
+        self.printErrorList("SKIPPED", self.skipped)
 
     def formatError(self, err):
         return "".join(format_exception(basedir=self.cfg.basedir,
@@ -726,6 +739,21 @@ class CustomTestResult(unittest._TextTestResult):
         w(self.formatError(err))
         w()
 
+    def printSkip (self, kind, test, err):
+        w = self.stream.writeln
+        if self.cfg.colorize:
+            c = colorize
+        else:
+            c = lambda texttype, text: text
+        w()
+        w(c('separator', self.separator1))
+        kind = c('fail', kind)
+        description = c('longtestname', self.getDescription(test))
+        w("%s: %s" % (kind, description))
+        w(c('separator', self.separator2))
+        w(str(err[1]))
+        w()
+
     def addFailure(self, test, err):
         if self.cfg.immediate_errors:
             self.printTraceback("FAIL", test, err)
@@ -745,9 +773,7 @@ class CustomTestResult(unittest._TextTestResult):
 
     def addSkipped(self, test, err):
         if self.cfg.immediate_errors:
-            self.printTraceback("SKIPPED", test, err)
-        if self.cfg.postmortem:
-            pdb.post_mortem(sys.exc_info()[2])
+            self.printSkip("SKIP", test, err)
         self.skipped.append((test, self.formatError(err)))
 
     def printErrorList(self, flavour, errors):
@@ -782,7 +808,7 @@ class CustomTestRunner(unittest.TextTestRunner):
     __super_init = __super.__init__
     __super_run = __super.run
 
-    def __init__(self, cfg, hooks=None, stream=sys.stderr, count=None):
+    def __init__(self, cfg, hooks=None, stream=sys.stdout, count=None):
         self.__super_init(verbosity=cfg.verbosity, stream=stream)
         self.cfg = cfg
         if hooks is not None:
@@ -915,11 +941,6 @@ def main(argv):
         elif k == '--coverage':
             cfg.coverage = True
         elif k == '--resource':
-            if v not in Resources:
-                print >> sys.stderr, ('%s: argument to --resource (%s) must'
-                                      ' be one of %s'
-                                      % (argv[0], v, str(Resources)))
-                return 1
             cfg.resources.append(v)
         elif k == '--level':
             try:
@@ -961,7 +982,8 @@ def main(argv):
         cfg.search_in = (cfg.basedir, )
 
     # Do not print "Imported %d modules in %.3fs" if --list-* was specified
-    if cfg.list_tests or cfg.list_hooks or cfg.list_files:
+    # or if quiet mode is enabled.
+    if cfg.quiet or cfg.list_tests or cfg.list_hooks or cfg.list_files:
         cfg.print_import_time = False
 
     # Set up the python path
